bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 20. Aventiure
___________________________________________________ #### Aventivre wie der chvnic ezele nah froen chriemhilt #### ze wormze sinen boten sande
###### 1143 | ### Daz was in einen citen | do vrov helche erstarp ### vnt daz der kvnich ecel | vmb ein ander vrowen warp ### do ritten sine vrivnde | in der bvrgondn lant ### ceiner stolcen wittewen | div was vrov criemhilt genant
###### 1144 | ### sit daz erstorben waere | der schonen helchen lip ### si sprachen welt ir immer | gewinnen edel wip ### di hohesten vnt di besten | di chvnich ie gewan ### so nemt di selben vrowen | der starche sifrit was ir man
###### 1145 | ### do sprach der chvnich riche | wi moht daz ergan ### sit ich pin ein heiden | vnt der tovffe nine han ### so ist div vrowe christen | davon so lobt sis niht ### ez mvese sin ein wunder | ob ez immer geschit
###### 1146 | ### do sprachen aber di snellen | waz ob siz lihte tvt ### dvrch iwern namen den hohen | vnd iwer michel gvt ### so sol man daz versvchen | an daz vil edel wip ### ir mveget vil gerne minnen | den ir vil waetlichen lip
###### 1147 | ### do sprach der kvnich edele | wem ist nv bechant ### vnder iv bi rine | di livte vnd ovch daz ### do sprach von bechelaren | der gvte rvedeger ### ich han erkant von kinde | di edelen chvenege her
###### 1148 | ### gvnther vnd gernot | di edeln ritter gvt ### der dritte heizet giselher | ir ietslicher tvt ### swaz er der besten eren | vnd tvgende mach began ### ovch hant ir alten mage | noch her daz selbe getan
###### 1149 | ### do sprach aber ecel | vrivnt dv solt mir sagen ### op si in minem lande | chrone solde tragen ### vnd ist ir lip so schoene | als mir ist geseit ### den minen besten vrivnden | sold ez nimmer werden leit
###### 1150 | ### si gelichet sich wol mit schoene | der lieben vrowen min ### helchen der vil richen | ia ne chonde niht gesin ### in dirre werlde schoener | deheines chvniges wip ### den si lobt ce vrivnde | der mach wol trosten sinen lip
###### 1151 | ### er sprach so wirb ez rvedeger | als liep als ich dir si ### vnd sol ich criemhilde | immer geligen bi ### des wil ich dir lonen | so ich allerbeste chan ### so hastv minen willen | so rehte verre getan
###### 1152 | ### vzzer miner chameren | so heiz ich dir geben ### daz dv vnt dine gesellen | mveget vroliche leben ### von rossen vnd von chleidern | allez daz dv wil ### des hiez ich iv bereiten | zv der botscheffte vil
###### 1153 | ### des antwurte rvdeger | der margrave rich ### gerte ich dines gvtes | daz waere vnlobelich ### ich wil din bote gerne | wesen an den rin ### mit min selbes gvte | daz ich han von der hende din
###### 1154 | ### do sprach der chvenich riche | nv wenne welt ir varn ### nach der minnechlichen | got sol ivch bewarn ### der reise an allen eren | vnt ovch di vrowen min ### des helfe mir gelveche | daz si vns genedich mvezze sin
###### 1155 | ### do sprach aber rvedger | e wir rvmen daz lant ### wir mvezzen e bereiten | waeffen vnt gewant ### also daz wirs ere | vor fvrsten mvgen han ### ich wil ce rine fveren | fvmfhvndert waetlicher man
###### 1156 | ### swa man cen bvrgonden | mich vnt di mine sehe ### daz ir ietslicher | danne dir dis iehe ### daz nie chvenech deheiner | also manigen man ### so verre baz gesande | danne dv ce rine hast getan
###### 1157 | ### vnd ob dvz kvenich riche | niht wil darvmb lan ### si was in edelen minnen | sifride vndertan ### dem sigemvndes chinde | den hastv hie gesehen ### man moht im rehter eren | mit maniger warheit iehen
###### 1158 | ### do sprach der kvnich edele | was si des recken wip ### so was wol also tivre | des edelen fvrsten lip ### daz ich niht versmahen | di chvneginne sol ### dvrch ir grozzen schone | so gevallet si mir wol
###### 1159 | ### do sprach der margrave | so wil iv daz sagen ### daz wir vns heben hinnen | in vier vnt zeweinzech tagen ### ich enbivte iz gotelinde | der lieben vrowen min ### daz ich nach criemhilde | selbe bote welle sin
###### 1160 | ### hin ce bechelaren | sande rvedeger ### do wart div margrave | trvrech vnd her ### er nbot ir daz er solde | dem chvnige werben wip ### si gedahte minnechliche | an der schonen helchen lip
###### 1161 | ### do div margravinne | di botschaft vernam ### ein teil was ir leide | weinens si gezam ### ob si gewinnen solde | vrowen alsam e ### so si gedaht an helchen | daz tet ir innechliche we
###### 1162 | ### rvedeger von vngern | in siben tagen reit ### des was der kvnech ecel | vro vnt gemeit ### da cer stat ce wiene | bereite man im wat ### do ne moht er siner reise | do niht langer haben rat
###### 1163 | ### da ce bechelaren | im warte gotelint ### div ivnge margravinne | daz rvdegeres chint ### sah ir vater gerne | vnt di sine man ### da wart ein liebes piten | von schoenen chinden getan
###### 1164 | ### e daz der edel rvedeger | ce bechelaren reit ### vz der stat ze wiene | do waren in ir chleit ### rehte vollechlichen | vf den sovmen chomen ### di fvren in der maze | daz in wart wenich iht genomen
###### 1165 | ### do si ce bechelaren | chomen in di stat ### di sinen reisgesellen | herbergen do bat ### der wirt vil minnechliche | vnt schvf in gvt gemach ### gotelint div riche | den wirt vil gerne chomen sach
###### 1166 | ### alsam tet sin liebiv tohter | dev ivnge margravin ### der ne chvnde nimmer | sin chomen lieber sin ### di helde vz hivnen landen | wi gerne si si sach ### mit lachendem mvte | div edele ivnchvrowe sprach
###### 1167 | ### nv si vns grozze willechomen | min vater vnd sine man ### do wart ein schoene danchen | mit vlize da getan ### der ivngen margravinne | von manigem ritter gvt ### vil wol wesse gotelint | des herren rvedegeres mvt
###### 1168 | ### do si des nahtes nahen | bi rvdgeren lach ### wi gvetliche vragen | div margravinne pflach ### war in gesendet hete | der chvenich von hevnen lant ### er sprach min vrowe gotelint | ich tvn dirz gern bechant
###### 1169 | ### da sol ich minem herren | werben ein ander wip ### sit daz ist verdorben | der schonen helchen lip ### ich wil nach criemhilde | riten an den rin ### div sol hi cen hivnen | gewaltech sin
###### 1170 | ### daz wolde got sprach gotelint | vnd mohte daz geschehen ### sit daz wir ir horen | so maniger eren iehen ### si ergazt vns miner vrowen | lihte in alten tagen ### ovch mohte wir si gerne | cen hivnen crone lazen tragen
###### 1171 | ### do sprach der margrave | trivtinne min ### di mit mir svlen riten | hinnen an den rin ### den svlt ir minnechliche | bieten iwer gvt ### so helde varent riche | so sint hohe gemvt
###### 1172 | ### si sprach ez ist deheiner | der iz gerne von mir nimt ### ine gebe ir ietslichem | swaz im wol gecimt ### e daz ir hinnen scheidet | vnd ovch iwer man ### do sprach der margrave | daz ist mir liebe getan
###### 1173 | ### hey waz man richer pfellel | von ir kamer trvch ### der wart den edelen recken | ce teile do genvch ### erfvllet vlizechlichen | von hals vnz vf den sporn ### di im darzv gevielen | di het im rvdger vzerchorn
###### 1174 | ### an dem sibendem morgen | von bechelaren reit ### der wirt mit sinen recken | waffen vnd chleit ### fvrten si den vollen | dvrh der beier lant ### si wurden vf der strazen | dvrch rovben selten angerant
###### 1175 | ### inner tagen zwelfen | si chomen an den rin ### do ne chvnden disiv maere | niht verholn sin ### man saget ez dem chvnige | vnt ovch sinen man ### ez choemen vremde geste | der wirt do vragen began
###### 1176 | ### ob iemen si bechande | man sold ez im sagen ### man sah ir sovmaere | so rehte swaere tragen ### daz si vil riche waren | daz wart da bechant ### man schvf in herberge | in der witen stat cehant
###### 1177 | ### do di vil vnchvnden | waren in bechomen ### do wart der selben herren | vaste wargenomen ### si wunderte wannen fveren | di recken an den rin ### der wirt nach hagen sande | ob si im chvndech moehten sin
###### 1178 | ### do sprach der helt von tronege| in han ir niht gesehen ### als wir si nv geschowen | ich chan iv wol veriehen ### von swann si riten | her in dizze lant ### si svlen sin vil vremde | ine hab si schiere bechant
###### 1179 | ### den gesten herberge | waren nv genomen ### in vil richiv chleider | was der bote bechomen ### vnd sine hergesellen | ce hove si do ritten ### si fvrten gvtiv chleider | vil harte spaehe gesnitten
###### 1180 | ### do sprach der snelle hagene | als ich mih chan verstan ### wande ich den herren lange | niht gesehen han ### si varent wol dem geliche | sam ez si rvdeger ### von hivnisschen landen | der recke chvne vnd her
###### 1181 | ### wi sol ich daz gelovben | sprach der kvenich zehant ### daz der von bechelaren | si chomen in dizz lant ### als der chvnich gvnther | di rede vol gesprach ### hagene der chvene | den gvten rvdegeren sach
###### 1182 | ### er vnt sine vrivnde | lieffen alle dan ### do sach man von den rossen | fvnfhvndert ritter stan ### do wurden wol enpfangen | di von hivnen lant ### boten nie getrvgen | also herlich gewant
###### 1183 | ### do sprach harte lvte | von tronege hagene ### nv sin gote willechomen | dise degene ### der voget von bechelaren | vnt alle sine man ### der antpfanch wart wol mit eren | den snellen hivnen getan
###### 1184 | ### des chveniges nehesten mage | di giengen da man sach ### ortwin von mezze | ce rvedgeren sprach ### wir haben in aller wile | mere nie gesehen ### geste hi so gern | des wil ich waerliche gehen
###### 1185 | ### des grvzzes si do danchten | den recken vber al ### mit den hergesinden | si giengen in den sal ### da si den chvenich fvnden | bi manigem herlichem man ### der herre stvnt von sedele | daz was dvrch groze zvht getan
###### 1186 | ### wi rehte zvehtechlichen | er zv den boten gie ### gvnther vnd giselher | vil vlizechlich enpfie ### den gast mit sinen mannen | als im wol gezam ### den gvten rvedger | er bi der hende genam
###### 1187 | ### er brahten zv dem sedele | da er selbe saz ### den gesten hiez man shenchen | vil gerne tet man daz ### met den vil gvten | vnt den besten win ### dem man chvnde finden | in dem lande al vmb den rin
###### 1188 | ### giselher vnd gere | di waren beide chomen ### dancwart vnd volcher | di heten ovch vernomen ### vmb dise geste | si waren vro gemvt ### si enpfiengen vor dem chvnige | di ritter edel vnd gvt
###### 1189 | ### do sprach ce sinem herren | von tronege hagene ### ez solden immer dienen | dise degene ### daz vns der margrave | ce liebe hat getan ### des solde lon enpfahen | der schoenen gotelinde man
###### 1190 | ### do sprach der kvnich gvnther | ine chan daz niht verdagen ### wi sich gehaben beide | daz svlt ir mir sagen ### ecel vnd helche | vzzer hivnen lant ### do sprach der margrave | ich tvn iz iv gerne bechant
###### 1191 | ### do stvnt er von dem sedele | mit allen sinen man ### er sprach zv dem chvenicge | vnd mach daz sin getan ### daz ir mir fvrste erlovbet | so ne wil ich niht verdagen ### div maere div ich bringe | sol ich iv vroliche sagen
###### 1192 | ### er sprach swaz man vns maere | bi iv enboten hat ### di erlovb ich iv ce sagene | ane vrivnde rat ### ir svlt si lazen horen | mich vnt mine man ### wand ich iv aller eren | hi ce werbene gan
###### 1193 | ### do sprach der bote biderbe | iv enbivtet an den rin ### getriwelichen dienest | der groze voget min ### darzv al den vrivnden | di ir mvegt han ### ovch ist disiv botschaft | mit grozen triwen getan
###### 1194 | ### iv bat der kvnich edele | chlagen sine not ### sin volch ist ane frevde | min frowe div ist tot ### helche di vil riche | mines herren wip ### an der nv ist verweiset | vil maniger ivnchvrowen lip
###### 1195 | ### chint der edeln fvrsten | div si gezogen hat ### davon iz ime lande | vil iamerliche stat ### din hant nv leider niemen | der ir mit triwen pflege ### des wen ovch sich vil seine | des chveniges sorge gelege
###### 1196 | ### nv lon im got sprach gvnther | daz er den dienest sin ### so willechlich enbivtet mir | vnt den vrivnden min ### den sinen grvz ich gerne | hie vernomen han ### daz svlen gerne dienen | beide mage vnt mine man
###### 1197 | ### do sprach von bvrgonden | der recke gernot ### in mag immer riwen | der schoenen helchen tot ### dvrch ir vil manige tvgende | der si chvnde pflegen ### der rede gestvnt im hagene | darzv vil manich ander degen
###### 1198 | ### do sprach aber rvedger | der edel bote her ### sit ir mir kvnich erlovbet | ich sol iv sagen mer ### waz iv min lieber herre | her enboten hat ### sit im sin dinch nach helchen | so rehte kvmmerlichen stat
###### 1199 | ### man sagt minem herren | criemhilt si ane man ### her sifrit si erstorben | vnd ist so getan ### welt ir ir des gvennen | so sol si chrone tragen ### vor eceln recken | daz hiez ir min herre sagen
###### 1200 | ### do sprach der kvnich riche | wol gezogen was sin mvt ### si horet minen willen | ob siz gerne tvt ### den wil ich iv chvenden | in disen drien tagen ### e ich ez an ir erfvnde | zwiv sold ich eceln versagen
###### 1201 | ### di wile man den gesten | hiez schaffen gvt gemach ### in wart da so gedienet | daz rvedeger des iach ### daz er da frivnde hete | vnder gvntheres man ### hagen im diente gerne | er het im e alsam getan
###### 1202 | ### alsvs beleip do gvnther | vnz an den dritten tach ### der kvnich nach rate sande | vil wislich er pflach ### ob ez sine mage | dvhte gvt getan ### daz criemhilt nemen solde | den kvenich eceln ce man
###### 1203 | ### si rieten al gemeine | niwan hagene ### der sprach | ce gvnther dem degene ### habt ir rehte sinne | so wirt ez wol behut ### ob sis iv volgen wolde | daz irz nimmer getvt
###### 1204 | ### warvmbe sprach do gvnther | sold ichs volgen niht ### swaz der chvneginne | liebes geschiht ### des sol ich ir wol gvennen | si ist div swester min ### wir soltenz selbe werben | op ez ir ere mohte sin
###### 1205 | ### do sprach aber hagene | lat di rede stan ### het ir eceln chvende | als ich sin chvende han ### sol sin danne minnen | als ich ivch hore iehen ### so ist iv allererste | von schvlden sorgen geschehen
###### 1206 | ### varvmb sprach do gvnther | ich behvte vil wol daz ### daz ich im chome so nahen | daz ich deheinen haz ### von im dvlden mvese | vnd waere sin wip ### do sprach aber hagene | ez geraetet nimmer min lip
###### 1207 | ### man hiez nach gernoten | vnd nach giselheren gan ### ob di herren beide | dvhte gvt getan ### daz criemhilt solde minnen | den richen kvnich her ### noch widerreit ez hagene | vnd nieman mer
###### 1208 | ### do sprach von bvrgonden | giselher der degen ### nv mvegt ir vrivnt hagene | noh der triwen pflegen ### ergezzet si der leide | vnd ir ir habt getan ### an swiv ir wol gelvnge | daz soldet ir vngeveht lan
###### 1209 | ### ia habt ir miner swester | getan so manegiv leit ### so sprach aber giselher | der recke vil gemeit ### daz si des hete schvlde | ob si iv waere gram ### nie man decheiner vrowen | noch mere frevdn benam
###### 1210 | ### daz ich daz wol bechenne | daz tvn ich iv chvnt ### sol si nemen ecel | gelebt si an di stvnt ### si getvt vns noch vil leide bswi siz getragt an ### ia wirt ir dienende | vil manich waetlicher man
###### 1211 | ### des antwurte hagenn | der chvne gernot ### ez mag also beliben | vnz an ir beider tot ### daz wir geriten nimmer | in eceln lant ### wir svln ir sin getriwe | daz ist ce den eren vns gewant
###### 1212 | ### do sprach aber hagene | mir mach niemen widersagen ### vnd sol div edele criemhilt | helchen chrone tragen ### si getvt vns noch vil leide | swi si gefvege daz ### ir svlt iz lan beliben | daz zimt iv recken michel baz
###### 1213 | ### mit zorn sprach do giselher | der schoenen vten svn ### wir svln doch niht alle | meinlichen tvn ### swaz eren ir geschehe | vro solten wir des sin ### swaz ir geredet hagene | ich dien ir dvrch di triwe min
###### 1214 | ### do daz gehorte hagene | do wart er vngemvt ### gernot vnd giselher | di stolzen ritter gvt ### vnd gventher der riche | ce ivngest reiten daz ### ob ez lobt criemhilt | si woltenz lazzen ane haz
###### 1215 | ### do sprach der fvrste gere | ich wilz der vrowen sagen ### daz si ir den kvenech ecel | laze wol behagen ### dem ist so manich recke | vnde grozen vorhten vndertan ### er mach si wol ergezzen | swaz ir leides ist getan
###### 1216 | ### do gie der snelle recke | da er crimhilde ### si enpfie in gvtliche | wi bald er do sprach ### ir mvegt mich gerne grvezzen | vnd geben botembrot ### ich wil iv gelvcke scheiden | vil schiere vz aller iwer not
###### 1217 | ### ez hat dvrch iwer minne | vrowe her gesant ### ein der allerbeste | der ie chveneges lant ### gewan mit vollen eren | oder chrone solde tragen ### ez werbent ritter edele | daz hiez iv iwer brvder sagen
###### 1218 | ### do sprach div iamers riche | iv sol verbieten got ### vnd allen minen vrivnden | daz si deheinen spot ### an mir armer veben | waz sold ich einem man ### der ie herceliebe | von gvtem wibe gewan
###### 1219 | ### si widerreit ez sere | do chom aber sint ### gernot ir brvder | vnt giselher daz chint ### da baten minnechliche | trosten si ir mvt ### ob si den kvnich genaeme | ez waer ir waerlichen gvt
###### 1220 | ### vberwinden chvnde | niemen do daz wip ### daz si minnen wolde | deheines mannes lip ### do baten si di degene | nv lazet doch gesehen ### ob ir anders niht getvt | daz ir den boten rvchet sehen
###### 1221 | ### daz eine wil ich niht versprechen | sprach daz vil edel wip ### ich en sehe gerne | den rvedgeres lip ### dvrch sine manige tvgende | waer er her niht gesant ### swerz ander boten waere | dem waer ich immer vmbechant
###### 1222 | ### si sprach ir svlt in morgen | hiezen her gan ### zv miner kemenate | ich wil in hoeren lan ### vil gar den minen willen | sol ich im selbe sagen ### ir wart eritteniwet | daz ir vil groezlichez clagen
###### 1223 | ### do gert ovch niht anders | der edel rvedger ### wan daz er gesaehe | di chvenegin her ### er weste sich so wisen | ob ez imer sold ergan ### daz si sich den recken | veberreden mvese lan
###### 1224 | ### des andern morgens vrv | do man di messe sanch ### di edeln boten chomn | do wart da groz gedranch ### di mite rvedgere | ce hove wolden gan ### do sah man da gechleidet | vil manigen herlichen man
###### 1225 | ### criemhilt div here | vnd vil trvrech gemvt ### si warte rvedger | dem edeln boten gvt ### der vant si in der waete | di si alle tage trvch ### dabi trvch ir gesinde | richer chleider genvch
###### 1226 | ### si giench im engegene | zv der tvr dan ### vnd enpfie vil gvtliche | den edeln man ### niwan selbe zwelfter | er dar zv ir gie ### man bot im grozen dienest | irn chomen hoher boten nie
###### 1227 | ### man hiez den herren sitzen | vnd sine man ### di zwene margraven | di sah man vor ir stan ### eckewart vnd gere | di edeln recken gvt ### dvrch di hvsvrowen | si sahen niemen wol gemvt
###### 1228 | ### si sahen vor ir sizzen | vil manich schoene wip ### do pflach niwan iamers | der criemhilde lip ### ir wat was vor den brvesten | von heizen traehen naz ### der edel margrave | sah wol an criemhilde daz
###### 1229 | ### do sprach der bote here | vil edeles chvniges chint ### mir vnt minen gesellen | di mit mir chomen sint ### svlt ir daz erlovben | daz wir vor iv stan ### vnd iv sagen maere | warnach wir her geritten han
###### 1230 | ### nv si iv erlovbet | sprach div chvenegin ### swaz ir reden wellet | also stat min sin ### daz ich ez gerne hore | ir sit ein bote gvt ### di andern do wol horten | ir vnwilligen mvt
###### 1231 | ### do sprach von bechelaren | der fvrste rvedger ### mit triwen groze liebe | ecel ein kvnich her ### hat iv enboten vrowe | her in dizze lant ### er hat nah iwer minne | vil gvte recken her gesant
###### 1232 | ### ern enbivtet iv innechlichen | minne ane leit ### staeter vrivntschefte | der si er iv bereit ### als er e tet vrovn helchen | div im ce hercen lach ### ia hat er nach ir tvgenden | vil diche vnvrolichen tach
###### 1233 | ### do sprach div chvneginne | margrave rvdger ### waer iemen der bechande | miniv starchen ser ### der baete mich niht trivten | noch deheinen man ### ia verlos ich ein den besten | den ie vrowe ie gewan
###### 1234 | ### waz mach ergezen leides | sprach der vil chvene man ### wan frivntliche liebe | swer di chan began ### vnt der dan einen chivset | der im ce rehte chvmt ### vor hercelicher leide | niht so grozliche frvmt
###### 1235 | ### vnd gervchet ir ce minnen | den edeln herren min ### zwelf vil richer chrone | svlt ir gewaltech sin ### darzv git iv min herre | wol drizech fvrsten lant ### div elliv hat betwungen | sin vil ellenthaftiv hant
###### 1236 | ### ir svlt ovch werden vrowe | vber manigen werden man ### di miner vrowen helchen | waren vndertan ### vnd veber manige vrowen | der si het gewalt ### von hoher fvrsten chvenne | sprach der chvene degen balt
###### 1237 | ### darzv git iv min herre | heizet er iv sagen ### ob ir gervchet chrone | bi dem kvenige tragen ### gewalt den allerhohesten | den helche ie gewan ### den svlt ir gewaltechliche | haben vor ecelen man
###### 1238 | ### do sprach div chvneginne | wi mohte min lip ### immer des gelvsten | deich wurde heldes wip ### mir hat der tot an einem | so rehte leit getan ### des ich vnz an min ende | mvz vnvroliche stan
###### 1239 | ### do sprachen aber di hivnen | kvneginne rich ### iwer leben wirt bi ecel | so reht lobelich ### daz ivch immer wundert | ist daz ez ergat ### want der kvnich riche | vil manigen cieren degen hat
###### 1240 | ### helchen ivnchvrowen | vnt iwer magedin ### solten di bi einander | ein gesinde sin ### dabi mohten recken | werden wol gemvt ### lat ez iv vrowe raten | ez wirt iv waerlichen gvt
###### 1241 | ### si sprach in ir zvehten | nv lat di rede stan ### vnze morgen vrv | so svlt ir her gan ### ich wil iv antwurten | des ir da habt mvt ### des mvsen do gevolgen | di recken chven vnde gvt
###### 1242 | ### do si cen herbergen | alle chomen dan ### do hiez div edel vrowe | nach giselhern gan ### vnd ovch nach ir mvter | den beden sagt si daz ### daz si gezaeme weinen | vnd niht anderes baz
###### 1243 | ### do sprach ir brvder giselher | swester mir ist geseit ### vnd wilz ovch wol gelovben | daz elliv diniv leit ### der kvnich ecel swende | vnd nimestvn ceinem man ### swaz iemen ander rate | so dvncht ez mich wol getan
###### 1244 | ### er mach dich wol ergezzen | sprach aber giselher ### vome rotten zv dem rine | von der elbe vnz an daz mer ### so ist kvenech deheiner | so gewaltech niht ### dv maht dich vrowen balde | so er din ce chonen giht
###### 1245 | ### si sprach min vil lieber brvder | zwiv raetestv mir daz ### chlagen vnd weinen | mir immer zaeme baz ### wi sold ich vor recken | da ce hove gan ### wart min lip ie schone | des pin ich ane getan
###### 1246 | ### do sprach div vrowe vte | ir lieben tohter zv ### swaz dine brvder raten | liebez chint daz tv ### volge dinen frivnden | so mach dir wol geshehen ### ich han dich doh so lange | mit grozem iamer gesehen
###### 1247 | ### do bat si got vil diche | fvegen ir den rat ### daz si ce geben hete | golt silber vnd wat ### sam e bi ir manne | do er noch was gesvnt ### si gelebte doch nimmer mere | sit so vroliche stvnt
###### 1248 | ### si gedahte in ir sinnen | vnd sol ich minen lip ### geben einem heiden | ich pin ein christen wip ### des mvz ich cer werlde | immer schaden han ### gaebe mir elliv riche | ez ist von mir vil vngetan
###### 1249 | ### damit siz lie beliben | di naht vnz an den tach ### div vrowe an ir bette | mit vil gedanchen lach ### div ir vil liehtv ovgen | getrvchenten nie ### vnz daz si aber den morgen | hin ce mettene gie
###### 1250 | ### ze rehter messecite | di chvnige waren chomen ### si heten aber ir swester | vnder hende genomen ### ia rieten si ir ze minnen | den kvnich von hivnen lant ### di vrowen ir deheiner | lvecel vroliche vant
###### 1251 | ### do hiez man dar gewinnen | di eceln man ### di nv mit vrlovbe | waeren gerne dan ### geworben oder gescheiden | swi ez do moehte sin ### ce hove chom do rvedger | di helde reiten vnder in
###### 1252 | ### daz man reht erfvere | des edeln fversten mvt ### vnd taeten daz becite | daz divhtes alle gvt ### ir wege waeren verre | wider in ir lant ### man brahte rvedegern | da er criemhilde vant
###### 1253 | ### vil minnechliche piten | der recke do began ### di edeln chveneginne | si solde in horen lan ### waz si enbieten wolde | in eceln lant ### er waen an ir niht anders | niwan lavgenen vant
###### 1254 | ### daz si nimmer minnen wolde | mer deheinen man ### do sprach der margrave | daz waere missetan ### zwiv woldet ir verderben | einn also schoenen lip ### ir mvegt noch mit eren | werden gvtes mannes wip
###### 1255 | ### niht half daz si gebaten | vnz rvedger ### si gesprach in heimliche | di chveneginne her ### er wolde si ergzen | swaz ir ie gesach ### ein teil begonde ir senften | do ir grozer vngemach
###### 1256 | ### er sprach cer kvneginne | lat iwer weinen sin ### ob ir ce hivnen hetet | niemen danne min ### getriwer miner mage | vnd ovch der miner man ### er mveses ser engelten | vnt het iv iemen iht getan
###### 1257 | ### davon wart wol geringet | do der vrowen mvt ### si sprach so swert mir eide | swaz mir iemen getvt ### daz ir sit der naehste | der bveze minv leit ### do sprach der margrave | vrowe des pin ich bereit
###### 1258 | ### mit allen sinen mannen | swur ir do rvedger ### mit triwen immer dienen | vnt daz di recken her ### ir nimmer niht versageten | vz eceln lant ### des si ere haben solde | des sichert ir rvedegers hant
###### 1259 | ### do gedahte div getriwe | sit ich vrivnde han ### also vil gewunnen | so sol ich reden lan ### di livte swaz wellen | ich iamerhaftez wip ### waz ob noch wirt errochen | des minen liebn mannes lip
###### 1260 | ### si gedahte sit daz ecel | der recken hat so vil ### sol ich den gebieten | so tvn ich swaz ich wil ### er ist ovch wol so riche | daz ich ce geben han ### mich hat der leidege hagene | mines gvtes an getan
###### 1261 | ### si sprach ce rvedgere | het ich daz vernomen ### daz er niht waere ein heiden | so wold ich gerne chomen ### swar er hete willen | vnd naem in ceinem man ### do sprah der margrave | di rede svlt ir vrowe lan
###### 1262 | ### er hat so vil der recken | in cristenlicher e ### daz iv bi dem chvenige | nimmer wirdet we ### waz ob ir daz verdienet | daz er tovffet sinen lip ### des mvegt ir gerne werden | des kvnich eceln wip
###### 1263 | ### do sprach aber ir brvder | nv lob iz swester min ### iwer vngemvete | daz svlt ir lazen sin ### si batens also lange | vnz doch ir trvrech lip ### lobte vor den helden | si wuerde eceln wip
###### 1264 | ### si sprach ich wil iv volgen | ich armiv kvnegin ### daz ich var zv den hivnen | so daz nv mach gesin ### swenne ich han di vrivnde | di mich fveren in sin lant ### des bot do vor den helden | div schone criemhilt ir hant
###### 1265 | ### do sprach der margrave | habt ir zwene man ### darzv han ich ir mere | ez wirdet wol getan ### daz wir ivch wol nach eren | bringen vber rin ### ir svlt niht vrowe langer | hi cen bvergonden sin
###### 1266 | ### ich han fvnhvndert manne | vnd ovch der mage min ### di svln iv hi dienen | vnt da heime sin ### vrowe swi ir gebietet | ich tvn iv selbe alsam ### swenne ir mich mant der maere | daz ich mich es nimmer gesham
###### 1267 | ### nv heizet iv bereiten | iwer pfaertchleit ### di rvedgeres raete | iv nimmer werden leit ### vnd sagetez iwern magedin | di ir da fveren welt ### ia chvmt vns vf der straze | vil manich vzerwelter helt
###### 1268 | ### si heten noch gesmide | daz man davor reit ### bi sifrides ziten | daz si vil manige meit ### mit eren mohte fveren | swenne si wolde dan ### hey waz man gvter saetele | den schoenen vrowen gewan
###### 1269 | ### ob si e ie getrvgen | deheiniv richen kleit ### der wart zv zir verte | vil manigez nv bereit ### wand in von dem kvnige | so vil gesaget wart ### si slvzen vf di chisten | di e stvnden wol bespart
###### 1270 | ### si waren vil vnmvezech | wol fvenftehalben tach ### si svchten vz der valden | des vil darinne lach ### criemhilt do ir kamer al | entslizen began ### si wolde machen riche | alle rvdegeres man
###### 1271 | ### si hete noch des goldes | von nibelvnge lant ### si wand ez cen hivnen | teiln solde ir hant ### daz ez wol hvndert moere | ninder chvnden tragen ### div maere horte hagene | do von criemhilde sagen
###### 1272 | ### er sprach sit mit vrov criemhilt | nimmer wirdet holt ### so mvz ovch hi belibn | daz sifrides golt ### zwiv sold ich minen finden | lan so michel gvt ### ich weiz wol waz criemhilt | mit disem shaze getvt
###### 1273 | ### ob si in brehte hinnen | ich wil gelovbn daz ### er wurde doch certeilet | vf den minen haz ### sin habnt ovch nicht der rosse | di in solden tragen ### in wil behalten hagene | daz sol man criemhilde sagen
###### 1274 | ### do si gehorte div maere | do was ir grimme leit ### ez wart ovch den kvenegen | allen drin geseit ### si woltenz gerne wenden | do des niht geschach ### rvedger der edele | harte vroliche sprach
###### 1275 | ### richiv chveneginne | zwiv chlagt ir daz golt ### iv ist der chvnich ecel | so grozlichen holt ### gesehent ivch siniv ovgen | er git iv also vil ### daz irz verswendet nimmer | des ich iv vrowe sweren wil
###### 1276 | ### do sprach div chveneginne | vil edel rvedger ### ez gewan chvniges tohter | nie richeite mer ### danne der mich hagene | ane hat getan ### do chom ir brvder gernot | hin zir kemenaten gegan
###### 1277 | ### mit gewalt des chveniges den slvezel | stiez er an di tver ### golt daz criemhilde | reichte man darfver ### ce drizech tvsent marchen | oder dannoch baz ### er hiez iz nemn di geste | liep was gvnthere daz
###### 1278 | ### do sprach von bechelaren | der gotelinde man ### ob ez min vrowe criemhilt | allez moehte han ### swaz sin ie wart gefveret | von nibelvnge lant ### sin solde lvecel rveren min | oder der kveneginne hant
###### 1279 | ### nv heizet ez behalten | wand ich es nine wil ### ia fvrt ich von lande | des minen also vil ### daz wirs vf der straze | haben gvten rat ### vnd vnser choste hinnen | harte herlichen stat
###### 1280 | ### davor in aller wile | gefvllet zwelf schrin ### des allerbesten goldes | daz inder mohte sin ### hete di ir megde | daz fvrt man von dan ### vnd gezierde vil der vrowen | daz si cir verte solde han
###### 1281 | ### gewalt des grimmen hagenen | dvhte si ce starch ### si het ir opffergoldes | noch wol tvsent march ### si teiltez siner sele | ir vil liebem man ### daz dvhte rvedgern | mit grozen triwen getan
###### 1282 | ### do sprach div chlagende vrowe | wa sint di vrivnde min ### di dvrch mine liebe | wellent ellende sin ### di svln mit mir riten | in der hivnen lant ### di nemen shaz den minen | vnd chovffen ros vnt ovch gewant
###### 1283 | ### do sprach cer kveneginne | der margrave eckewart ### sit daz ich allerste | iwer gesind wart ### so han ich iv mit triwen | gedient sprach der degen ### vnd wil vnz an minen ende | des selben immer bi iv pflegen
###### 1284 | ### ich wil ovch mit mir fveren | fvnfhvndert minen man ### der ich iv ce dienste | mit rehten triwen gan ### wir sin vil vngescheiden | ez en tv dan der tot ### der rede neig im criemhilt | des gie ir waerliche not
###### 1285 | ### do zoch man dan di moere | si wolden varn dan ### da wart vil michel weinen | von vrivnden getan ### vte div vil riche | vnd manich schone meit ### di zeigeten daz in waere | nach vrovn criemhilde leit
###### 1286 | ### hvndert richer magede | fvrt si mit ir dan ### di wurden so gechleidet | als in wol gezam ### do vielen in di trehene | von liehten ovgen nider ### si gelebt vil der vrevden | ovch bi eceln sider
###### 1287 | ### do chom der herre giselher | vnd ovch gernot ### mit ir gesinde | als in ir zvht gebot ### do wolden si beleiten | ir liebe swester dan ### do fvrten si ir rechen | wol tvsent waetlicher man
###### 1288 | ### do chom der snelle gere | vnd ovch ortwin ### rvmolt der chvchenmeister | damite mvse sin ### si svffen di nahtselde | vnz an tvonowe stat ### do reit niht fverbaz gvnther | wan ein lvecel fvr di stat
###### 1289 | ### e si von rine fveren | si heten fver gesant ### ir boten harte snelle | in der hivnen lant ### di dem chvnige sageten | daz im rvedger ### ce wibe het erworben | di edeln kvneginne her

<<< Übersicht <<< vorige Seite nächste Seite >>>